<?php
/**
 * CT White Theme Customizer
 *
 * @package CT_White
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ct_white_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'ct_white_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'ct_white_customize_partial_blogdescription',
			)
		);
	}

	$wp_customize->add_section(
		'ct_white_single_layout', array(
			'title'		=>	__('Single Post', 'ct-white'),
			'priority'	=>	50
		)
	);

	$wp_customize->add_setting(
		'ct_white_fimage_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_fimage_enable', array(
			'label'		=>	__('Show Featured Image', 'ct-white'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_white_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_white_single_date_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_single_date_enable', array(
			'label'		=>	__('Show Date', 'ct-white'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_white_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_white_single_author_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_single_author_enable', array(
			'label'		=>	__('Show Author', 'ct-white'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_white_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_white_single_cats_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_single_cats_enable', array(
			'label'		=>	__('Show Categories (Post Footer)', 'ct-white'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_white_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_white_single_tags_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_single_tags_enable', array(
			'label'		=>	__('Show Tags (Post Footer)', 'ct-white'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_white_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_white_single_nav_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_single_nav_enable', array(
			'label'		=>	__('Show Post Navigation', 'ct-white'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_white_single_layout',
		)
	);

	$wp_customize->add_section('ct_white_social_section', array(
			'title' 	=> esc_html__('Social Icons','ct-white'),
			'priority' 	=> 70
	));

	$wp_customize->add_setting(
		'ct_white_social_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_white_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_white_social_enable', array(
			'label'	=>	__('Show Social Icons in Header', 'ct-white'),
			'type'	=>	'checkbox',
			'section'	=>	'ct_white_social_section',
			'priority'	=>	5
		)
	);

	$social_networks = array( //Redefinied in Sanitization Function.
					'none' 		=> esc_html__('-','ct-white'),
					'facebook' 	=> esc_html__('Facebook', 'ct-white'),
					'twitter' 	=> esc_html__('Twitter', 'ct-white'),
					'instagram' => esc_html__('Instagram', 'ct-white'),
					'rss' 		=> esc_html__('RSS Feeds', 'ct-white'),
					'youtube' 	=> esc_html__('Youtube', 'ct-white'),
					'twitch' 	=> esc_html__('Twitch', 'ct-white'),
					'xing'		=> esc_html__('Xing', 'ct-white')
				);


    $social_count = count($social_networks);

	for ($s = 1 ; $s <= ($social_count - 3) ; $s++) :

		$wp_customize->add_setting(
			'ct_white_social_' . $s, array(
				'sanitize_callback' => 'ct_white_sanitize_social',
				'default' 			=> 'none',
			));

		$wp_customize->add_control( 'ct_white_social_' . $s, array(
					'settings' 	=> 'ct_white_social_' . $s,
					'label' 	=> esc_html__('Icon ','ct-white') . $s,
					'section' 	=> 'ct_white_social_section',
					'type' 		=> 'select',
					'choices' 	=> $social_networks,
		));

		$wp_customize->add_setting(
			'ct_white_social_url'.$s, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'ct_white_social_url' . $s, array(
			'label' 		=> esc_html__('Icon ','ct-white') . $s . esc_html__(' Url','ct-white'),
					'settings' 		=> 'ct_white_social_url' . $s,
					'section' 		=> 'ct_white_social_section',
					'type' 			=> 'url',
					'choices' 		=> $social_networks,
		));

	endfor;

	function ct_white_sanitize_social( $input ) {
		$social_networks = array(
					'none' ,
					'facebook',
					'twitter',
					'instagram',
					'rss',
					'youtube',
					'twitch',
					'xing'
				);
		if ( in_array($input, $social_networks) )
			return $input;
		else
			return '';
	}

	$wp_customize->add_section(
		'ct_white_theme_options', array(
			'title'			=>	__('Theme Options', 'ct-white'),
			'priority'		=>	30
		)
	);

	$wp_customize->add_setting(
		'ct_white_mobile_menu_btn_text', array(
			'default'		=>	__('MENU', 'ct-white'),
			'sanitize_callback'	=>	'sanitize_text_field',
			'transport'		=>	'postMessage'
		)
	);

	$wp_customize->add_control(
		'ct_white_mobile_menu_btn_text', array(
			'label'		=>	__('Mobile Menu Button Text', 'ct-white'),
			'priority'	=>	10,
			'section'	=>	'ct_white_theme_options'
		)
	);

	//Client Showcase Section
	$wp_customize->add_section(
        'ct_white_client_showcase_options',
        array(
            'title'     => __('Client Showcase','ct-white'),
            'priority'  => 60,
        )
    );

    $wp_customize->add_setting(
        'ct_white_client_showcase_enable',
        array( 'sanitize_callback' => 'ct_white_sanitize_checkbox' )
    );

    $wp_customize->add_control(
        'ct_white_client_showcase_enable', array(
            'settings' => 'ct_white_client_showcase_enable',
            'label'    => __( 'Enable Client Showcase', 'ct-white' ),
			'description'	=>	__('For Blog Page only', 'ct-white'),
            'section'  => 'ct_white_client_showcase_options',
            'type'     => 'checkbox',
            'default'  => false,
        )
    );

    $wp_customize->add_setting( 'ct_white_client_showcase_title' , array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control(
        'ct_white_client_showcase_title', array(
        'label' => __('Title','ct-white'),
        'section' => 'ct_white_client_showcase_options',
        'settings' => 'ct_white_client_showcase_title',
        'type' => 'text',
    ) );

    $wp_customize->add_setting(
        'ct_white_client_showcase_columns',
        array(
            'sanitize_callback' => 'ct_white_sanitize_select',
            'default' => '3'
        )
    );

    $wp_customize->add_control(
        'ct_white_client_showcase_columns',array(
            'label' => __('Number of Columns','ct-white'),
            'settings' => 'ct_white_client_showcase_columns',
            'section'  => 'ct_white_client_showcase_options',
            'type' => 'select',
            'choices' => array(
                '2' => __('2 Columns','ct-white'),
                '3' => __('3 Columns','ct-white'),
                '4' => __('4 Columns','ct-white')
            ),
        )
    );


    $wp_customize->add_setting('ct_white_client_logo',
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control(
        new CT_White_Gallery_Control(
            $wp_customize, 'ct_white_client_logo',
            array (
                'setting' => 'ct_white_client_logo',
                'section' => 'ct_white_client_showcase_options',
                'label' => __('Client Logos', 'ct-white'),
				'description'	=>	__('NOTE: For Best Results, upload images with resolution 600x600', 'ct-white')
            )
        )
    );
}
add_action( 'customize_register', 'ct_white_customize_register' );

/**
 *	Sanitization of Checkbox
 */
 function ct_white_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}

//Sanitization of Select
function ct_white_sanitize_select( $input, $setting ) {

    //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
    $input = sanitize_key($input);

    //get the list of possible select options
    $choices = $setting->manager->get_control( $setting->id )->choices;

    //return input if valid or return default option
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ct_white_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ct_white_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ct_white_customize_preview_js() {
	wp_enqueue_script( 'ct-white-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), CT_WHITE_VERSION, true );
}
add_action( 'customize_preview_init', 'ct_white_customize_preview_js' );
